Package: geosapi
Type: Package
Title: GeoServer REST API R Interface
Version: 0.8-1
Date: 2026-07-22
Authors@R: c(person("Emmanuel", "Blondel", role = c("aut", "cre"), email = "emmanuel.blondel1@gmail.com", comment = c(ORCID = "0000-0002-5870-5762")))
Maintainer: Emmanuel Blondel <emmanuel.blondel1@gmail.com>
Description: Provides an R interface to the GeoServer REST API, allowing to upload 
 and publish data in a GeoServer web-application and expose data to OGC Web-Services. 
 The package currently supports all CRUD (Create,Read,Update,Delete) operations
 on GeoServer workspaces, namespaces, datastores (stores of vector data), featuretypes,
 layers, styles, as well as vector data upload operations. For more information about 
 the GeoServer REST API, see <https://docs.geoserver.org/main/en/user/rest/>.
Depends: R (>= 3.1.0)
Imports: R6, cli, openssl, httr, xml2, magrittr, keyring, readr
Suggests: testthat, waldo, roxygen2, shiny, knitr, markdown
License: MIT + file LICENSE
URL: https://github.com/eblondel/geosapi,
        https://eblondel.github.io/geosapi/, https://geoserver.org/
BugReports: https://github.com/eblondel/geosapi/issues
LazyLoad: yes
RoxygenNote: 7.3.3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-07-22 07:28:04 UTC; emman
Author: Emmanuel Blondel [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-5870-5762>)
Repository: CRAN
Date/Publication: 2026-07-22 08:20:02 UTC
