# Generated by roxygen2: do not edit by hand

export(GSAbstractCoverageStore)
export(GSAbstractDBDataStore)
export(GSAbstractDataStore)
export(GSAbstractStore)
export(GSAccessControlListManager)
export(GSArcGridCoverageStore)
export(GSCoverage)
export(GSCoverageBand)
export(GSCoverageStoreManager)
export(GSCoverageView)
export(GSDataStoreManager)
export(GSDimension)
export(GSFeatureDimension)
export(GSFeatureType)
export(GSGeoPackageDataStore)
export(GSGeoTIFFCoverageStore)
export(GSImageMosaicCoverageStore)
export(GSInputCoverageBand)
export(GSLayer)
export(GSLayerGroup)
export(GSLayerManager)
export(GSLayerRule)
export(GSManager)
export(GSMetadataLink)
export(GSMonitorManager)
export(GSNamespace)
export(GSNamespaceManager)
export(GSOracleNGDataStore)
export(GSPostGISDataStore)
export(GSPublishable)
export(GSRESTEntrySet)
export(GSRESTResource)
export(GSResource)
export(GSRestRule)
export(GSRule)
export(GSServiceManager)
export(GSServiceRule)
export(GSServiceSettings)
export(GSShapefileDataStore)
export(GSShapefileDirectoryDataStore)
export(GSShinyMonitor)
export(GSStyle)
export(GSStyleManager)
export(GSUtils)
export(GSVersion)
export(GSVirtualTable)
export(GSVirtualTableGeometry)
export(GSVirtualTableParameter)
export(GSWorkspace)
export(GSWorkspaceManager)
export(GSWorkspaceSettings)
export(GSWorldImageCoverageStore)
import(cli)
import(httr)
import(keyring)
import(magrittr)
import(xml2)
importFrom(R6,R6Class)
importFrom(openssl,base64_encode)
importFrom(readr,read_csv)
importFrom(readr,write_csv)
