**geosapi**
===========

[![Build Status](https://github.com/eblondel/geosapi/actions/workflows/r-cmd-check.yml/badge.svg?branch=master)](https://github.com/eblondel/geosapi/actions/workflows/r-cmd-check.yml)
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/geosapi)](https://cran.r-project.org/package=geosapi)
[![cran checks](https://badges.cranchecks.info/worst/geosapi.svg)](https://cran.r-project.org/web/checks/check_results_geosapi.html)
[![Github_Status_Badge](https://img.shields.io/badge/Github-0.8--1-blue.svg)](https://github.com/eblondel/geosapi)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.1184895.svg)](https://doi.org/10.5281/zenodo.1184895)

``geosapi``: GeoServer REST API R Interface

### Citation

We thank in advance people that use ``geosapi`` for citing it in their work / publication(s). For this, please use the citation provided at this link [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.1184895.svg)](https://doi.org/10.5281/zenodo.1184895)

### User Manual

A user manual is available at [https://github.com/eblondel/geosapi/wiki](https://github.com/eblondel/geosapi/wiki)

The R package is also documented through its [website](https://eblondel.github.io/geosapi/)

### Sponsors

Many thanks to the following organizations that have provided fundings for strenghtening the ``geosapi`` package:

<a href="https://unepgrid.ch/en"><img height=100 width=200 src="https://unepgrid.ch/themes/grid/assets/dist/images/grid-logo-black-en.svg"></a><a href="https://www.fao.org/home/en/"><img height=100 width=200 src="https://www.fao.org/fileadmin/templates/family-farming-decade/images/FAO-IFAD-Logos/FAO-Logo-EN.svg"></a>
<a href="http://www.cnrs.fr"><img src="http://www.cnrs.fr/themes/custom/cnrs/logo.svg" height=100 width=100/></a>
<a href="https://letg.cnrs.fr"><img height=100 width=50 src="https://letg.cnrs.fr/wp-content/uploads/2023/05/logo_letg.png"></a>
