#' @name geosapi
#' @aliases geosapi-package
#' @aliases geosapi
#' 
#' @title GeoServer REST API R Interface
#' @description Provides an R interface to the GeoServer REST API, allowing to 
#' upload and publish data in a GeoServer web-application and expose data to OGC 
#' Web-Services. The package currently supports all CRUD (Create,Read,Update,Delete) 
#' operations on GeoServer workspaces, namespaces, datastores (stores of vector data), 
#' featuretypes, layers, styles, as well as vector data upload operations. For 
#' more information about the GeoServer REST API, see <https://docs.geoserver.org/main/en/user/rest/> .
#'  
#'@author Emmanuel Blondel \email{emmanuel.blondel1@@gmail.com}
#'
"_PACKAGE"