% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GSVirtualTableParameter.R
\docType{class}
\name{GSVirtualTableParameter}
\alias{GSVirtualTableParameter}
\title{Geoserver REST API GSVirtualTableParameter}
\format{
\code{\link[R6]{R6Class}} object.
}
\value{
Object of \code{\link[R6]{R6Class}} for modelling a GeoServer virtual table parameter
}
\description{
Geoserver REST API GSVirtualTableParameter

Geoserver REST API GSVirtualTableParameter
}
\examples{
GSVirtualTableParameter$new(name = "fieldname", defaultValue = "default_value",
                            regexpValidator = "someregexp")

}
\author{
Emmanuel Blondel <emmanuel.blondel1@gmail.com>
}
\keyword{api}
\keyword{geoserver}
\keyword{rest}
\keyword{virtualTable}
\section{Super class}{
\code{\link[geosapi:GSRESTResource]{geosapi::GSRESTResource}} -> \code{GSVirtualTableParameter}
}
\section{Public fields}{
\if{html}{\out{<div class="r6-fields">}}
\describe{
\item{\code{name}}{parameter name}

\item{\code{defaultValue}}{parameter default value}

\item{\code{regexpValidator}}{parameter regexp validator}
}
\if{html}{\out{</div>}}
}
\section{Methods}{
\subsection{Public methods}{
\itemize{
\item \href{#method-GSVirtualTableParameter-new}{\code{GSVirtualTableParameter$new()}}
\item \href{#method-GSVirtualTableParameter-decode}{\code{GSVirtualTableParameter$decode()}}
\item \href{#method-GSVirtualTableParameter-clone}{\code{GSVirtualTableParameter$clone()}}
}
}
\if{html}{\out{
<details open><summary>Inherited methods</summary>
<ul>
<li><span class="pkg-link" data-pkg="geosapi" data-topic="GSRESTResource" data-id="encode"><a href='../../geosapi/html/GSRESTResource.html#method-GSRESTResource-encode'><code>geosapi::GSRESTResource$encode()</code></a></span></li>
<li><span class="pkg-link" data-pkg="geosapi" data-topic="GSRESTResource" data-id="getClassName"><a href='../../geosapi/html/GSRESTResource.html#method-GSRESTResource-getClassName'><code>geosapi::GSRESTResource$getClassName()</code></a></span></li>
<li><span class="pkg-link" data-pkg="geosapi" data-topic="GSRESTResource" data-id="print"><a href='../../geosapi/html/GSRESTResource.html#method-GSRESTResource-print'><code>geosapi::GSRESTResource$print()</code></a></span></li>
</ul>
</details>
}}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-GSVirtualTableParameter-new"></a>}}
\if{latex}{\out{\hypertarget{method-GSVirtualTableParameter-new}{}}}
\subsection{Method \code{new()}}{
Initializes an object of class \link{GSVirtualTableParameter}
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{GSVirtualTableParameter$new(xml = NULL, name, defaultValue, regexpValidator)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{xml}}{object of class \link[xml2]{xml_node-class}}

\item{\code{name}}{name}

\item{\code{defaultValue}}{default value}

\item{\code{regexpValidator}}{regexp validator}
}
\if{html}{\out{</div>}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-GSVirtualTableParameter-decode"></a>}}
\if{latex}{\out{\hypertarget{method-GSVirtualTableParameter-decode}{}}}
\subsection{Method \code{decode()}}{
Decodes from XML
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{GSVirtualTableParameter$decode(xml)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{xml}}{object of class \link[xml2]{xml_node-class}}
}
\if{html}{\out{</div>}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-GSVirtualTableParameter-clone"></a>}}
\if{latex}{\out{\hypertarget{method-GSVirtualTableParameter-clone}{}}}
\subsection{Method \code{clone()}}{
The objects of this class are cloneable with this method.
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{GSVirtualTableParameter$clone(deep = FALSE)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{deep}}{Whether to make a deep clone.}
}
\if{html}{\out{</div>}}
}
}
}
